#version 330

uniform sampler2DRect inputTex;
uniform sampler2DRect inputTex1;
uniform float transitionProgress=1.0;
uniform float transitionAlpha=1.0;
uniform float baseAlpha=1.0;
uniform int transitionState;
uniform int direction=0;
uniform sampler2DRect maskTex;
in vec2 fsMaskTexture;


in vec2 fsTexture;
in vec2 fsTexture2;
in vec2 fsTextureNormalized;
out vec4 outColor;

void main()
{
	 vec4 colorA = texture(inputTex, fsTexture)*baseAlpha;
	 vec4 colorB = texture(inputTex1, fsTexture2)*baseAlpha;
	 
	 float diffIn;
	 float diffOut;
	 
	 switch(direction)
	 {
		  case 0: //top left
		  {
				float tp=transitionProgress*1.1;
				
				diffIn=tp-(fsTextureNormalized.x+fsTextureNormalized.y)*.5;
				diffOut=(fsTextureNormalized.x+fsTextureNormalized.y)*.5-(tp-.1);
				break;
		  }
		  case 1: //top center
		  {
				float tp=(1.0-transitionProgress)*1.1;
				
				diffIn=fsTextureNormalized.y-(tp-.1);
				diffOut=tp-fsTextureNormalized.y;
				break;
		  }
		  case 2: //top right
		  {
				float tp=transitionProgress*1.1;
				diffIn=tp-(fsTextureNormalized.x+fsTextureNormalized.y)*.5;
				diffOut=(fsTextureNormalized.x+fsTextureNormalized.y)*.5-(tp-.1);
				break;
		  }
		  case 3: //middle left
		  {
				float tp=transitionProgress*1.1;
				
				diffIn=tp-fsTextureNormalized.x;
				diffOut=fsTextureNormalized.x-(tp-.1);
				break;
		  }
		  case 4: //middle center - not used
		  {
				float tp=transitionProgress*1.1;
				
				diffIn=tp-fsTextureNormalized.x;
				diffOut=fsTextureNormalized.x-(tp-.1);
				break;
		  }
		  case 5: //middle right
		  {
				float tp=(1.0-transitionProgress)*1.1;
				
				diffIn=fsTextureNormalized.x-(tp-.1);
				diffOut=tp-fsTextureNormalized.x;
				break;
		  }
		  case 6: //bottom left
		  {
				float tp=transitionProgress*1.1;
				
				diffIn=tp-(fsTextureNormalized.x+fsTextureNormalized.y)*.5;
				diffOut=(fsTextureNormalized.x+fsTextureNormalized.y)*.5-(tp-.1);
				break;
		  }
		  case 7: //bottom center
		  {
				float tp=transitionProgress*1.1;
				
				diffIn=tp-fsTextureNormalized.y;
				diffOut=fsTextureNormalized.y-(tp-.1);
				break;
		  }
		  case 8: //bottom right
		  {
				float tp=transitionProgress*1.1;
				diffIn=tp-(fsTextureNormalized.x+fsTextureNormalized.y)*.5;
				diffOut=(fsTextureNormalized.x+fsTextureNormalized.y)*.5-(tp-.1);
				break;
		  }
	 }
	 
	 
	 diffIn=clamp(diffIn*10.0,0.0,1.0);
	 diffOut=clamp(diffOut*10.0,0.0,1.0);
	 outColor=colorA*diffIn+colorB*diffOut;
#ifdef USE_MASK
	 outColor.a*=texture(maskTex,fsMaskTexture).a;
#endif
}


